@@ -10,8 +10,10 @@ fn filter_resources(bench: &mut Bench) {
     bench.task("filter resources", |task| {
         let package_dir = std::env::var_os("CARGO_MANIFEST_DIR").expect("manifest dir not set");
         let paths = vec![PathBuf::from(package_dir).join("test-data/")];
-        let mut args = Args::default();
-        args.silent_load = true;
+        let args = Args {
+            silent_load: true,
+            ..Default::default()
+        };
         let base = LogBase::new(&paths, &args).unwrap();
         assert_eq!(base.lines.len(), 33468);
         task.iter(|| {
